function [ mapping,onlyCoreMapping ] = SVCHuClustering( data, p, q )
%SVCHUCLUSTERING Summary of this function goes here
%   Detailed explanation goes here

data = data';
[samples,dims] = size(data);
C = 1/(p * samples);
lables = ones(samples,1);
assignInOut = ones(samples,1);
% run the SVM algorithm
cmd = ['-s 2 -t 2 -g ', num2str(q), ' -n ', num2str(p)];
model = libsvmtrain(lables,data, cmd );

%get the model data
nSV = model.totalSV;
betas = model.sv_coef;


%get the unscaled betas
betas = betas .* C;

SVs = [model.SVs(1:nSV,:)];

%calculate the quadradic part of R (doesn't change for all points)
quadratic = 0;
for iSV=1:nSV
      D2=sum(((repmat(SVs(iSV,:),nSV,1)-SVs).^2)');
      singlePoint=exp(-q*D2)';
     quadratic = quadratic + sum(betas.*singlePoint)*betas(iSV);
end;
    
    
  %  for jSV=1:nSV
    %    kernel = exp(-q*(norm(SVs(iSV,:) - SVs(jSV,:))^2));
      %  quadratic = quadratic + betas(iSV)*betas(jSV)*kernel;
   % end;
%end;


% in some scenarios there are some accuracy problems (1e-4) so take the
% biggest radius for the calculations
SVRadius = zeros(nSV,1);
for iSV=1:nSV
    if(betas(iSV)  < C)
        SVRadius(iSV) = calculateDistanceToCenter(betas, SVs, nSV, SVs(iSV,:),quadratic, q);
    end;
end;

R = max(SVRadius);
for n=1:samples
    point = data(n,:);
       if(calculateDistanceToCenter(betas, SVs, nSV, point,quadratic, q) > R)
          assignInOut(n)=0; 
       end;
end;

corePtsNum = sum(assignInOut);
corePtsInd = zeros(corePtsNum,1);
corePts = zeros(corePtsNum,dims);
coreCounter = 1;
for n=1:samples
    if (assignInOut(n) == 1)
        corePtsInd(coreCounter) = n;
        corePts(coreCounter,:) = data(n,:);
        coreCounter = coreCounter + 1;
    end;
end;

[coreMapping,optK] = SilhouetteKmeans(corePts);
tmpMapping = zeros(samples,1);

for n=1:corePtsNum
    tmpMapping(corePtsInd(n)) = coreMapping(n);
end;
onlyCoreMapping = tmpMapping;
for n=1:samples
    if(assignInOut(n)==0)
        minDist = bitmax;
        point = data(n,:);
        closeIndex = 0;
         for m=1:corePtsNum
                dist = norm(point - corePts(m,:));
                if(dist < minDist)
                    closeIndex = m;
                    minDist = dist;
               end;
        end;
        tmpMapping(n) = coreMapping(closeIndex);
     end;
end;
   
mapping = tmpMapping;
  

end

% calculate the distance to the center of the sphere. (get the quadratic
% part as already calculated to save time
function [ R ] = calculateDistanceToCenter(betas, SVs, nSV, point, quadratic, q )
  D2=sum(((repmat(point,nSV,1)-SVs).^2)');
  singlePoint=exp(-q*D2)';
  linear = sum(betas.*singlePoint);
  R = 1 - 2*linear + quadratic; 
end
