%SVCLUSTERING Summary of this function goes here
%   This function gets the data and p and q values. p stand for the
%   percentage of outlayers and q the coefficient of the exponent
function [ mapping ] = SVClustering(data, p, q )

data = data';
[samples,dims] = size(data);
C = 1/(p * samples);
lables = ones(samples,1);
%mapping = zeros(samples,1);

% run the SVM algorithm
cmd = ['-s 2 -t 2 -g ', num2str(q), ' -n ', num2str(p)];
model = libsvmtrain(lables,data, cmd );

%get the model data
nSV = model.totalSV;
betas = model.sv_coef;


%get the unscaled betas
betas = betas .* C;

SVs = [model.SVs(1:nSV,:)];

%calculate the quadradic part of R (doesn't change for all points)
quadratic = 0;
for iSV=1:nSV
      D2=sum(((repmat(SVs(iSV,:),nSV,1)-SVs).^2)');
      singlePoint=exp(-q*D2)';
     quadratic = quadratic + sum(betas.*singlePoint)*betas(iSV);
end;


% in some scenarios there are some accuracy problems (1e-4) so take the
% biggest radius for the calculations
SVRadius = zeros(nSV,1);
for iSV=1:nSV
    if(betas(iSV)  < C)
        SVRadius(iSV) = calculateDistanceToCenter(betas, SVs, nSV, SVs(iSV,:),quadratic, q);
    end;
end;

R = max(SVRadius);
%adjacency matrix
AMat = ones(samples);
AMat = AMat * -1;
%fill the adjacency matrix - for each two points divide the linear path to
%20 and check that all of them are inside the sphere radius if so 
%A(i,j) = 1  else A(i,j) = 0

for n=1:samples
    point = data(n,:);
       if(calculateDistanceToCenter(betas, SVs, nSV, point,quadratic, q) > R)
            for m=1:samples   
                AMat(n,m) = 0;
                AMat(m,n) = 0;
            end;
       end;
end;

for n=1:samples
       AMat(n,n) = 1;
end;

for n=1:samples
    startPoint = data(n,:);
    for m=n+1:samples
         if (AMat(n,m) == -1)
            endPoint = data(m,:);
            intervals = 20;
             path = endPoint - startPoint;
             length = norm(path);
            dir = path/length;
            stepSize = length / intervals;
            inside = true;
            step = 0;
          while(inside && step < intervals + 1)
              point = startPoint + dir*(step * stepSize );
              if(calculateDistanceToCenter(betas, SVs, nSV, point,quadratic, q) > R)
                  inside = false;
              end;
              step = step +1;
          end;
          if(inside == false)
                 AMat(n,m) = 0;
                 AMat(m,n) = 0;
          else
             	AMat(n,m) = 1;
                AMat(m,n) = 1;
           end;        
        end;
    end;
end;

%find the connected components
sparseAMat = sparse(AMat);
[numClusters, clusters] =  graphconncomp(sparseAMat);

%find the closest cluster to each BSV
clusterEntries = histc(clusters, 1:1:numClusters);
tmpMapping = zeros(samples,1);
for n=1:samples
    %if the cluster consist of one point it's BSV
    if (clusterEntries(clusters(n)) == 1)
        minDist = bitmax;
        closeIndex = 0;
        point = data(n,:);
        for m=1:samples
            if(clusterEntries(clusters(m)) > 1)
                dist = norm(point - data(m,:));
                if(dist < minDist)
                    closeIndex = m;
                    minDist = dist;
                end;
            end;
        end;
        tmpMapping(n) = clusters(closeIndex);
    else
        %it's not a BSV just get what got out of the SVM
        tmpMapping(n) = clusters(n);
    end;
end;
%change the clusters to start with 1 2 3.... 
lastClusterIndex = 1;
for n=1:samples
    if(tmpMapping(n) >= lastClusterIndex)
        tmpMapping(tmpMapping==tmpMapping(n)) = lastClusterIndex;
        lastClusterIndex = lastClusterIndex+1;
    end;
end;
mapping = tmpMapping;
end

% calculate the distance to the center of the sphere. (get the quadratic
% part as already calculated to save time
function [ R ] = calculateDistanceToCenter(betas, SVs, nSV, point, quadratic, q )
  D2=sum(((repmat(point,nSV,1)-SVs).^2)');
  singlePoint=exp(-q*D2)';
  linear = sum(betas.*singlePoint);
%linear = 0;
%for jSV=1:nSV
  %        kernel = exp(-q*(norm(point - SVs(jSV,:))^2));
    %       linear = linear + betas(jSV)*kernel;
%end;
R = 1 - 2*linear + quadratic; 

end

