% function [jaccard,purity,efficiency]=calculateJaccardByReference(algorithm,real)
%   Calculate thr jaccard purity,efficiency values for each one of the
%   clusters (in contrast to the 'by pairs' calculation)
% Input:
%   algorithm - the clusters tags as suggested by the algorithm
%   real - the true clusters tags
% Output:
%   jaccard - jaccard values vector - size of the vector == number of true (real) clusters (jaccard(ind) = n11/(n11+n10+n01);)
%   purity - purity values vector - size of the vector == number of true (real) clusters (purity(ind) = n11/(n11+n01);)
%   efficiency - efficiency values vector - size of the vector == number of true (real) clusters (efficiency(ind) = n11/(n11+n10);)
function [jaccard,purity,efficiency]=calculateJaccardByReference(algorithm,real)
newClassification=relabelClassificationFromReference(algorithm,real);% relablel the vector
jaccard=zeros(max(real),1);
purity=zeros(max(real),1);
efficiency=zeros(max(real),1);

for ind =1: max(real)
    realClass = find(real == ind);
    algoClass = find(newClassification==ind);
    n11 = length(intersect(realClass,algoClass));
    n10 =length(setdiff(realClass,algoClass));
    n01 =length(setdiff(algoClass,realClass));
    if n11>0
        jaccard(ind) = n11/(n11+n10+n01);
        purity(ind) = n11/(n11+n01);
        efficiency(ind) = n11/(n11+n10);  
    else
        jaccard(ind)=0;
        purity(ind)=0;
        efficiency(ind)=0;
    end
end