%   function [,mapping ]= cnnClustering(steps,learningRate,dims)
%   Description run a competitive clustering algorithm 
%   #1 read input from xls file, and truncate the relative dimensions
%   #2 train and simulate a competitive network
%   Input:
%   steps - number of steps for the training set
%   learningRate - learning rate for the network
%   data - dims( = number of dimensions)*# samples
%   numOfClusters - number of required clusters
%
%   Output:
%   mapping - classification (control Vs sick)
function [mapping ]= cnnClustering(steps,learningRate,data,dispWaitBar,numOfClusters)
if nargin < 4
    dispWaitBar = 1;% true
end
if dispWaitBar
    h = waitbar(0,'Please wait...');
end
data = data';
[dims,samples] =size(data);
if nargin <5 || numOfClusters <2
    numOfClusters = dims;
end
% Competitive NN!!
% note: the weight vector must be asymmetrical!!! 
maxMat = ones(1,dims);% all ones
minMat = maxMat -2; % all -1
minMaxMat = [minMat;maxMat];
net = newc(minMaxMat',numOfClusters,learningRate);%create competitive NN 
if dispWaitBar
    waitbar(10/100)
end
w = net.IW{1};
net.trainParam.epochs = steps;
if dispWaitBar
    waitbar(20/100)
end
net = train(net,data); %   train the network
w = net.IW{1}; % retrieve the new centers
if dispWaitBar
    waitbar(80/100)
end
a = sim(net,data);%run the trained network on the same input
mapping = vec2ind(a);% put in an integer vector
if dispWaitBar
    waitbar(100/100)
    close(h) 
end