function D=graddesc(xyData,q,steps,eta,rescale,showProgress)
% function graddesc(xyData,q,[steps])
% purpose: performing quantum clustering in and moving the 
%          data points down the potential gradient
% input: xyData - the data vectors
%        q=a parameter for the parsen window variance (q=1/(2*sigma^2))
%        steps=number of gradient descent steps (default=50)
% output: D=location of data o=point after GD 
if nargin < 3 
    steps=50;
end
if nargin < 6
    showProgress=0;
end

if showProgress
    h = waitbar(0,'Quantum Clustering is running. Please wait...');
end
if nargin < 4
    eta = 0.1;
end
if nargin < 5
   rescale = 0;
end
D=xyData;
[V,P,E,dV] = qc (xyData,q,D);
for j=1:4
   for i=1:(steps/4)
       dV=normc(dV')';
       D=D-eta*dV;
       if (rescale)
          D=normr(D);
       end
       [V,P,E,dV] = qc (xyData,q,D);
       if showProgress
           waitbar(( (((j-1)*steps)/4)+i)/steps)
       end    
   end
   %eta=eta*0.5;
end
if showProgress
    close(h)
end

