function [D,ascent]=graddesc(xyData,q,steps,showProgress)
% function graddesc(xyData,q,[steps])
% purpose: performing quantum clustering in and moving the 
%          data points down the potential gradient
% input: xyData - the data vectors
%        q=a parameter for the parsen window variance (q=1/(2*sigma^2))
%        steps=number of gradient descent steps (default=50)
% output: D=location of data o=point after GD 
% ascent; = location of data o=point after gradient ascent
if nargin<3 
    steps=50;
end
if nargin <4
    showProgress=0;
end
if showProgress
    h = waitbar(0,'Quantum Clustering is running. Please wait...');
end

eta=0.1;
D=xyData;
ascent=xyData;
[V,P,E,dV] = qc (xyData,q,D);

Vascent=max(V) -V;
dVascent=-dV ;
for j=1:4
   for i=1:(steps/4)
       dV=normc(dV')';
       dVascent=--dVascent;
       dVascent=normc(dVascent')';
       D=D-eta*dV;%descent
       ascent = ascent-eta*dVascent;%ascent
       [V,P,E,dV] = qc (xyData,q,D);
       [Vascent,Pascent,Eascent,dVascent] =qc(xyData,q,ascent);
       Vascent=max(Vascent)-Vascent;
       if showProgress
           waitbar(( (((j-1)*steps)/4)+i)/steps)
       end    
   end
   eta=eta*0.5;
end
if showProgress
    close(h)
end

