% function [calcMapping]= pureQC(sigma,steps,percent)
% Desrciption: run QC and label only the most <percent> significant elements
%                   (those that are close to the minima).
%   Input:  
%   data - the elements to be cluster
%   sigma - sigma for qc
%   steps - number of iterations in the qc
%   percent - percent of significant elements in the dataset (range: [1  100])
%   show - if it is in silent mode - don't show progress
%   Output:
%   mapping - labels of the elements (some '0' might appear in case where
%   globalMin - the cluster in which the global minimum lies
%   percent < 100)
function [calcMapping,globalMin]= pureQC(data, sigma,steps,percent,show,doRecurse)
qcMapping= qcClustering(sigma,steps,data,doRecurse,show);
calcMapping = zeros(size(qcMapping));%allocate vecotr for output
q=1/(2*sigma^2);
[V,P,E,dV] = qc (data,q); % calculate the potential
nClusts = max(qcMapping);
for ind = 1: nClusts
    clustInd = find (qcMapping == ind);% find the elements in the cluster
    clustV = V(clustInd);% find their potentials
    [sortedPotentialVec,sortedPotentialInd] = sort(clustV);% sort the elements by ascending order
    if sortedPotentialVec(1) ==0
        globalMin = ind;% the cluster in which the global minimum lies
    end
    numOfElementsToInclude = round((percent/100) * length(clustInd));
    pureElementsInClusterVec =  sortedPotentialInd(1:numOfElementsToInclude);
    pureElementsInVec = clustInd(pureElementsInClusterVec);
    calcMapping(pureElementsInVec) = ind;
end