% function [mapping] = qcClustering(sigma,steps,data)
% performs quantum clustering + gradient descent
% Input -
% sigma - as in the algorithm
% steps - number of steps
% data - dims*samples matrix
% doRecurse - if 1, then call the methods again - if not use the
% bestCluster
% numOfClusters - number of clusters
% Output -
% mapping results of the algorithm
function [mapping,mappingAscent,minV] = qcClustering(sigma,steps,data,doRecurse,numOfClusters)
[dims,samples] = size(data);
if nargin<4 || doRecurse ==1
    doRecurse=1;
end
if nargin <5 ||   numOfClusters<2
    numOfClusters = dims;
end
q=1/(2*sigma^2);
[D,ascent]=graddesc(data,q,steps,doRecurse);   % performs gradient descent on xyData with steps + show progress bar (only in a recurse mode
%mapping = referenceClustering(D,numOfClusters);
D(find(isnan(D))) = 0;
dMax = sum((max(D) - min(D)).^2);
if dMax ==0
    errordlg('Points could not converge','Bad Input','modal');  
    D = data;
    dMax= sum((max(D) - min(D)).^2);
end
if doRecurse ==1
     [V,P,E,dV] = qc (data,q,D);% calculate the potential of the new points
     minV=find(V==0);
     newData = [D,V] ;% the new data is the converged points + the potential
    mapping = qcClustering(sigma,1,newData,0);% call again -- the recursion (only once more)
else
    dist=sigma/2;
    if dMax/steps < dist
        dist = dMax/steps;
    end
    mapping =fineCluster(D,dist)';
end
