%   function [familyTree, partitionMatrix]=recCompact(filename,show)
%   Recursive/ Devide & Conquer  Quantum Clustering
%   Input
%   filename    -   the file that holds the set of parameters for the
%   algorithm
%   show - boolean parameter [0/1] 1 is only for debug mode
%   Output
%   familyTree- A Cell based data structure representation of the hierarchy
%   partitionMatrix - a partition matrix representation of the hierarchy
%   (equivalent to the previous)
%   For more information on the we refer to tree2partition function
%   (type "help  tree2partition")
function [familyTree,partitionMatrix]=recCompact(filename,show,debug)
tic
if nargin <3 %no show option
    debug = 0;
end
inputStruct = readInputFile(filename);% initiate the parameters for the algorithm
fatherDims = num2str(1:inputStruct.numelems);
[familyTree] =recCompactInternal (inputStruct,fatherDims,[],debug);%actual call to algorithm
toc
[partitionMatrix]= tree2partition(familyTree);%the equivalent (more practical representation of the tree)
if nargin >1 && show
    plotRecTree(familyTree,inputStruct,partitionMatrix-1);%the last is for the enrichment display
end
toc
%recursive internal call
function [familyTree] =recCompactInternal (inputStruct,fatherDims,familyTree,show)
length(str2num(fatherDims));
[cnt,y] = size(familyTree);
cnt = cnt +1;

calcMapping=1;%dummy start
originalSigma= inputStruct.sigma;%for later

[calcMapping,jm,efficiency, purity,globalMin]    =silentCompareMethodsTool([],show,inputStruct,fatherDims);
while max(max(calcMapping)) ==1
    inputStruct.sigma=inputStruct.sigma*.8;%make the sigma smaller...
    [calcMapping,jm,efficiency, purity,globalMin]    =silentCompareMethodsTool([],show,inputStruct,fatherDims);
end
%now we are back in business...
inputStruct.sigma=originalSigma;
minSetIds = find(calcMapping == globalMin);
minSetName = num2str(minSetIds');


otherSetsIds = find((calcMapping ~= globalMin) & (calcMapping ~= 0) );
otherSetsName = num2str(otherSetsIds');
familyTree(cnt,1) = {fatherDims};
familyTree(cnt,2) = {minSetName};
familyTree(cnt,3) = {otherSetsName};

% call two recursive calls
if length(minSetIds)>2
    [familyTree] =recCompactInternal (inputStruct,minSetName,familyTree,show);
elseif length(minSetIds)==2
    familyTree(cnt+1,1) = {minSetName};
    familyTree(cnt+1,2) = {num2str(minSetIds(1))};
    familyTree(cnt+1,3) = {num2str(minSetIds(2))};
end
if length(otherSetsIds)>2
    [familyTree] =recCompactInternal (inputStruct,otherSetsName,familyTree,show);
elseif length(otherSetsIds)==2
    [cnt,y] = size(familyTree);
    cnt = cnt +1;
    familyTree(cnt,1) = {otherSetsName};
    familyTree(cnt,2) = {num2str(otherSetsIds(1))};
    familyTree(cnt,3) = {num2str(otherSetsIds(2))};
end






