%function [socMapping]=secondOrderClustering(soc,data, display)
%function [socMapping]=secondOrderClustering(soc,data, display)
function [socMapping]=secondOrderClustering(soc,data, display)
[samples,dims] = size(data);
eyes = eye(samples);
socMat= zeros(size(eyes));%secon order clustering
h = waitbar(0,'Second Order Clustering is running. Please wait...');
times =0;
if  soc.kmeans.check
    times = times +  soc.kmeans.sols;%number of steps for kmeans
end
if  soc.fcm.check
    times = times +  soc.fcm.sols;%number of steps for fcm
end
if  soc.nn.check
    times = times +  soc.nn.sols;%number of steps for nn
end
if  soc.qc.check
    times = times + 1;%One step for qc
end
if times <=0 % ERROR!!!
    errordlg('You must select at least one algorithm','Bad Input','modal');
end
cnt =0;
if soc.kmeans.check%kmeans
    socKmeans = zeros(size(eyes));
    for ind = 1: soc.kmeans.sols
        waitbar(cnt/times)
        cnt = cnt +1;
        kmeansMapping = kmeans(data,soc.kmeans.clust);
        pairs= establishPairsMatrix (kmeansMapping);
        socKmeans =socKmeans + pairs +pairs'+eyes;
    end
    socKmeans =socKmeans/soc.kmeans.sols; % normalize
    socKmeans= socKmeans* soc.kmeans.weight;% multiply with the weight
    socMat=socMat+socKmeans;
end
if soc.fcm.check%fcm
    socFcm = zeros(size(eyes));
    for ind = 1: soc.fcm.sols
        waitbar(cnt/times)
        cnt = cnt +1;
        fcmMapping =   referenceClustering(data,soc.fcm.clust,soc.fcm.exp,soc.fcm.iters,   soc.fcm.eps, soc.fcm.info);
        pairs= establishPairsMatrix (fcmMapping);
        socFcm =socFcm + pairs +pairs'+eyes;
    end
    socFcm =socFcm/soc.fcm.sols; % normalize
    socFcm= socFcm* soc.fcm.weight;% multiply with the weight
    socMat=socMat+socFcm;
end

if soc.nn.check%nn
    socNn = zeros(size(eyes));
    for ind = 1: soc.nn.sols
        waitbar(cnt/times)
        cnt = cnt +1;
        nnMapping =       cnnClustering(soc.nn.iters,    soc.nn.learn, data,display,   soc.nn.clust);
        pairs= establishPairsMatrix (nnMapping);
        socNn =socNn + pairs +pairs'+eyes;
    end
    socNn =socNn/soc.nn.sols; % normalize
    socNn= socNn* soc.nn.weight;% multiply with the weight
    socMat=socMat+socNn;
end

if soc.qc.check%qc
    socQc = zeros(size(eyes));
    waitbar(cnt/times)
    cnt = cnt +1;
    qcMapping =qcClustering(soc.qc.sigma,soc.qc.iters, data);%next time will move to pure
    pairs= establishPairsMatrix (qcMapping);
    socQc=socQc + pairs +pairs'+eyes;
    socQc= socQc* soc.qc.weight;% multiply with the weight
    socMat=socMat+socQc;
end
maxSoc=max(max(socMat));
if maxSoc>0
    socMat=(maxSoc-socMat)/maxSoc;
end


%now we finished the distance matrix creation. Second order clustering
%starts at compression and clustering
[normVector, numberOfGenes, numberOfSamples]= guiTruncateInputWithSelectedDims(socMat, 1,[1:dims],0, 1,1);
if soc.qc.check%qc
    socMapping =qcClustering(soc.qc.sigma,soc.qc.iters, normVector);%next time will move to pure
elseif soc.kmeans.check%kmeans
    socMapping =kmeans(normVector,soc.kmeans.clust);%(soc.qc.iters,soc.qc.sigma, socMat);%next time will move to pure
elseif soc.fcm.check%fcm
    socMapping = referenceClustering(normVector,soc.fcm.clust,soc.fcm.exp,soc.fcm.iters,   soc.fcm.eps, soc.fcm.info);
elseif soc.nn.check%fcm
    socMapping = cnnClustering(soc.nn.iters,    soc.nn.learn, normVector,display,   soc.nn.clust);
end
close(h);